@@ -1,4 +1,4 @@
-#!/usr/bin/electron13
+#!/usr/lib/electron25/electron
 // don't edit the electron binary name here! simply change the variable in the PKGBUILD and we will sed it into the correct one :)
 
 const name = 'code-oss';
